package com.olimex.bmp085;

import java.util.ArrayList;

import com.olimex.libi2c.libI2C;
import com.olimex.mod_bmp085.R;
import com.stericson.RootTools.RootTools;
import com.stericson.RootTools.execution.CommandCapture;

import android.os.Bundle;
import android.os.Handler;
import android.app.Activity;
import android.app.Dialog;
import android.app.ProgressDialog;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.NumberPicker;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends Activity implements View.OnClickListener {

	BMP085 bmp;
	Button btnConnectDisconnect;
	Button btnStart;
	Button btnStop;
	TextView txttemperature;
	TextView txtpressure;
	TextView txtaltitude;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		

		final ProgressDialog gain_permission = ProgressDialog.show(this,
				"Please wait", "Gaining permissions...", true);

		btnConnectDisconnect = (Button) findViewById(R.id.buttonConnect);
		btnStart = (Button) findViewById(R.id.buttonStart);
		btnStop = (Button) findViewById(R.id.buttonStop);

		txttemperature = (TextView) findViewById(R.id.txtTemperature);
		txtpressure = (TextView) findViewById(R.id.txtPressure);
		txtaltitude = (TextView) findViewById(R.id.txtAltitude);

		txttemperature.setText("null");
		txtpressure.setText("null");
		txtaltitude.setText("null");

		bmp = new BMP085(getApplicationContext());
		libI2C.ADDRESS = 0x77;
		libI2C.BUS = "/dev/i2c-2";
		

		new Thread(new Runnable() {
			@Override
			public void run() {

				try {
					CommandCapture command = new CommandCapture(0, "su", "-c",  "chmod 777 /dev/i2c-*");
					RootTools.getShell(true).add(command);
					Thread.sleep(2000);

				} catch (Exception e) {
					e.printStackTrace();
				}
				gain_permission.dismiss();

			}
		}).start();

		if (!BMP085.isConnected)
			btnConnectDisconnect.setText(R.string.button_connect);
		else
			btnConnectDisconnect.setText(R.string.button_disconnect);

		btnStart.setOnClickListener(this);
		btnStop.setOnClickListener(this);
		btnConnectDisconnect.setOnClickListener(this);

		final Handler handler = new Handler();
		
	    Runnable runnable = new Runnable() {
	    	
	        @Override
			public void run() {
	            while (true) {  
	                try {
	                    Thread.sleep(500);
	                }    
	                catch (InterruptedException e) {
	                    e.printStackTrace();
	                }
	                handler.post(new Runnable(){
	                    @Override
						public void run() {
	                    	txttemperature.setText(String.format("%.1fC", bmp.getTemperature()));
	                    	txtpressure.setText(String.format("%.2fhPa", bmp.getPressure()));
	                    	txtaltitude.setText(String.format("%.2fm", bmp.getAltitude()));
	                }
	            });
	            }
	        }
	    };
	    
	    new Thread(runnable).start();

	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);

		return true;
	}

	@Override
	public boolean onMenuItemSelected(int featureId, MenuItem item) {

		switch (item.getItemId()) {
		case R.id.settings_i2c_0:
			item.setChecked(true);
			libI2C.BUS = "/dev/i2c-0";
			Toast.makeText(getApplicationContext(), R.string.toast_i2c_0,
					Toast.LENGTH_SHORT).show();
			return true;

		case R.id.settings_i2c_1:
			item.setChecked(true);
			libI2C.BUS = "/dev/i2c-1";
			Toast.makeText(getApplicationContext(), R.string.toast_i2c_1,
					Toast.LENGTH_SHORT).show();
			return true;

		case R.id.settings_i2c_2:
			item.setChecked(true);
			libI2C.BUS = "/dev/i2c-2";
			Toast.makeText(getApplicationContext(), R.string.toast_i2c_2,
					Toast.LENGTH_SHORT).show();
			return true;

		case R.id.action_address:
			final Dialog d = new Dialog(MainActivity.this);
			d.setTitle("Select address");
			d.setContentView(R.layout.dialog_address);
			Button b1 = (Button) d.findViewById(R.id.buttonOK);
			Button b2 = (Button) d.findViewById(R.id.buttonCancel);
			final NumberPicker np = (NumberPicker) d
					.findViewById(R.id.numberPicker1);
			ArrayList<String> str_values = new ArrayList<String>();
			for (int i = 0x03; i < 0x78; i++) {
				str_values.add(String.format("0x%02X", i));
			}
			String[] arr = str_values.toArray(new String[str_values.size()]);
			np.setMinValue(1);
			np.setMaxValue(str_values.size());
			np.setDisplayedValues(arr);
			d.show();
			b1.setOnClickListener(new View.OnClickListener() {
				@Override
				public void onClick(View v) {
					
					libI2C.ADDRESS = np.getValue() + 0x02;
					Toast.makeText(
							getApplicationContext(),
							String.format("Selected address: 0x%02X",
									libI2C.ADDRESS), Toast.LENGTH_LONG).show();
					d.dismiss();
				}
			});
			b2.setOnClickListener(new View.OnClickListener() {

				@Override
				public void onClick(View v) {
					d.dismiss();
				}
			});
			return true;
		case R.id.settings_oss_0:
			item.setChecked(true);
			bmp.OSS = 0;
			Toast.makeText(getApplicationContext(),
					String.format("Selected oversampling: 0x%02X", bmp.OSS),
					Toast.LENGTH_LONG).show();
			return true;
		case R.id.settings_oss_1:
			item.setChecked(true);
			bmp.OSS = 1;
			Toast.makeText(getApplicationContext(),
					String.format("Selected oversampling: 0x%02X", bmp.OSS),
					Toast.LENGTH_LONG).show();
			return true;
		case R.id.settings_oss_2:
			item.setChecked(true);
			bmp.OSS = 2;
			Toast.makeText(getApplicationContext(),
					String.format("Selected oversampling: 0x%02X", bmp.OSS),
					Toast.LENGTH_LONG).show();
			return true;
		case R.id.settings_oss_3:
			item.setChecked(true);
			bmp.OSS = 3;
			Toast.makeText(getApplicationContext(),
					String.format("Selected oversampling: 0x%02X", bmp.OSS),
					Toast.LENGTH_LONG).show();
			return true;
		default:
			return super.onMenuItemSelected(featureId, item);
		}

	}

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.buttonConnect:
			if (!BMP085.isConnected) {
				if (bmp.Connect()) {
					btnConnectDisconnect.setText(R.string.button_disconnect);
					btnStart.setEnabled(true);
				}
			} else {
				bmp.Disconnect();
				btnConnectDisconnect.setText(R.string.button_connect);
				btnStart.setEnabled(false);
			}
			break;
		case R.id.buttonStart:
			btnStop.setEnabled(true);
			btnStart.setEnabled(false);
			btnConnectDisconnect.setEnabled(false);
			bmp.start();

			break;
		case R.id.buttonStop:
			btnStop.setEnabled(false);
			btnStart.setEnabled(true);
			btnConnectDisconnect.setEnabled(true);
			bmp.stop();
			bmp.temperature = 0;
			bmp.pressure = 0;
			bmp.altitude = 0;

		}

	}

}
